#!/bin/bash

#########################################################################
# This program is free software: you can redistribute it and/or modify  #
# it under the terms of the version 3 of the GNU General Public License #
# as published by the Free Software Foundation.                         #
#                                                                       #
# This program is distributed in the hope that it will be useful, but   #
# WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      #
# General Public License for more details.                              #
#                                                                       #
# You should have received a copy of the GNU General Public License     #
# along with this program. If not, see <http://www.gnu.org/licenses/>.  #
#                                                                       #
# Written by and Copyright (C) Francois Fleuret                         #
# Contact <francois.fleuret@idiap.ch> for comments & bug reports        #
#########################################################################


set -e
set -o pipefail

tmp=$(mktemp /tmp/arxiv-bib.sh.XXXXXX)

while [[ "$1" ]]
do

    id="$1"

    if [[ ${id} =~ ^http ]]
    then
        id="$(echo "${id}" | sed -e 's|^.*/\([^\]*\)$|\1|')"
    fi

    curl -s > "${tmp}" "https://arxiv.org/abs/${id}"

    AUTHORS=""

    while read line
    do
        [[ "${AUTHORS}" ]] && AUTHORS="${AUTHORS} and "
        AUTHORS="${AUTHORS}${line}"
    done < <(grep '<meta name="citation_author"' "${tmp}" | sed -e 's/^.*content="\([^,]*, .\).*$/\1./')

    TITLE=$(grep '<meta name="citation_title"' ${tmp} | sed -e 's/^.*content="\([^"]*\)".*$/\1/')
    YEAR=$(echo ${id} | sed -e 's/^\(..\).*$/20\1/')

    cat <<EOF
@article{arxiv-${id},
  author={${AUTHORS}},
  title={${TITLE}},
  journal={CoRR},
  volume={abs/${id}},
  year={${YEAR}},
  url={https://arxiv.org/pdf/${id}}
}
EOF

    shift

done



      rm -rf ${tmp}
